# Audit: ADR-0.17.0-agentsmd-tidy-control-surface-schema-and-rules-mir

- ADR: `docs\design\adr\pre-release\ADR-0.17.0-agentsmd-tidy-control-surface-schema-and-rules-mir\ADR-0.17.0-agentsmd-tidy-control-surface-schema-and-rules-mir.md`

## Results
- **test**: PASS (`uv run gz test`) -> `docs\design\adr\pre-release\ADR-0.17.0-agentsmd-tidy-control-surface-schema-and-rules-mir\audit\proofs\test.txt`
- **lint**: PASS (`uv run gz lint`) -> `docs\design\adr\pre-release\ADR-0.17.0-agentsmd-tidy-control-surface-schema-and-rules-mir\audit\proofs\lint.txt`
- **typecheck**: PASS (`uv run gz typecheck`) -> `docs\design\adr\pre-release\ADR-0.17.0-agentsmd-tidy-control-surface-schema-and-rules-mir\audit\proofs\typecheck.txt`
- **docs**: PASS (`uv run mkdocs build --strict`) -> `docs\design\adr\pre-release\ADR-0.17.0-agentsmd-tidy-control-surface-schema-and-rules-mir\audit\proofs\docs.txt`
